#
# spec file for package double-conversion
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lib_ver 3
%define libname libdouble-conversion3
Name:           double-conversion
Version:        3.3.1
Release:        1.1
Summary:        Binary-decimal and decimal-binary routines for IEEE doubles
License:        BSD-3-Clause
URL:            https://github.com/google/double-conversion
Source0:        https://github.com/google/double-conversion/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source99:       baselibs.conf
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  python3-base

%description
Double-conversion provides binary-decimal and decimal-binary routines
for IEEE double-precision floating point numbers. The library
consists of conversion routines that have been extracted from the V8
JavaScript engine.

%package     -n %{libname}
Summary:        Binary-decimal and decimal-binary routines for IEEE doubles

%description -n %{libname}
Double-conversion provides binary-decimal and decimal-binary routines
for IEEE double-precision floating point numbers. The library
consists of conversion routines that have been extracted from the V8
JavaScript engine.

%package        devel
Summary:        Development files for BCD/DCB routines for IEEE doubles
Requires:       %{libname} = %{version}

%description    devel
Double-conversion provides binary-decimal and decimal-binary routines
for IEEE double-precision floating point numbers. The library
consists of conversion routines that have been extracted from the V8
JavaScript engine.

This package provides libraries and header files for developing applications
that use double-conversion.

%prep
%autosetup -p1

%build
%cmake \
    -DBUILD_SHARED_LIBS:BOOL=ON\
    -DBUILD_TESTING:BOOL=ON
%cmake_build

%install
%cmake_install

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
%ctest

%ldconfig_scriptlets -n %{libname}

%files -n %{libname}
%license LICENSE
%{_libdir}/libdouble-conversion.so.%{lib_ver}{,.*}

%files devel
%license LICENSE
%doc AUTHORS Changelog README.md
%{_libdir}/libdouble-conversion.so
%{_libdir}/cmake/%{name}/
%{_includedir}/%{name}/

%changelog
* Sat Apr  5 2025 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.3.1:
  * Add _ITERATOR_DEBUG_LEVEL=2 and _DEBUG defines
  * Build system and CI tweaks
  * Add some missing headers
* Mon Jun 19 2023 Dirk Müller <dmueller@suse.com>
- update to 3.3.0:
  * Fix some compile warnings in Visual Studio
  * Set permissions for github workflows
  * Add flags to control trailing decimal and zero in exponent
    form when input has one significant digit
* Wed Aug 17 2022 Dirk Müller <dmueller@suse.com>
- update to 3.2.1
  * Disable quiet nan test on windows
  * Test on all platforms.
  * Fix warnings on Windows
  * Run ctests first.
  * Give shared-lib option and test install
  * Install Windows debbuger (pdb) files.
  * Add a cast to silence a signedness conversion warning.
  * Issue #184 : Fixed all -Wzero-as-null-pointer-constant warnings
* Sat Apr  9 2022 Dirk Müller <dmueller@suse.com>
- update to 3.2.0:
  * Fix quiet NANs on MIPS* and PA-RISC architectures.
* Thu Dec 30 2021 Dirk Müller <dmueller@suse.com>
- update to 3.1.7:
  * Reintroduce macros, if DOUBLE_CONVERSION_NON_PREFIXED_MACROS is set
  * Also add support for Synopsys ARC64 architecture
* Sun Dec  5 2021 Dirk Müller <dmueller@suse.com>
- update to 3.1.6:
  * Features some code cleanups.
  * Adds the following new architectures: loongarch, xtensa, nios2, e2k.
* Thu Feb  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Use proper cmake calls
- Do not pull in py2 that is EOL but use python3 for build
* Mon Jul 22 2019 Todd R <toddrme2178@gmail.com>
- Update to version 3.1.5 jsc#ECO-1190, jsc#SLE-11474
  * Fix `0x` for string->double conversion when Hex Floats are allowed.
    Avoid integer overflow when exponents for hex floats were too big.
    Update version number.
  * Fixed warning in gcc4.9.
  * Merged changes to install libraries in the correct place when
    using 64-bit libraries.
  * Use relative includes in the library. This shouldn't have any visible effect
    for consumers of the library.
  * Fix typo in test.
  * Fix separator characters when they they don't fit into 8 bits.
  * Check correctly for _MSC_VER.
  * Allow the library to be compiled for Emscripten.
* Thu Feb 28 2019 Andreas Schwab <schwab@suse.de>
- Update to version 3.0.3
  * Support RISC-V
  * Bug fixes
- Switch to cmake
- Use %%license
* Fri Jul 14 2017 jengelh@inai.de
- Fix RPM groups.
  Slightly trim/compact descriptions.
* Wed Oct  5 2016 zaitor@opensuse.org
- Add baselibs.conf: Build 32-bit support (boo#1002561).
* Mon Feb  1 2016 mpluskal@suse.com
- Update project and download urls
- Cleanup spec file with spec-cleaner
* Thu Jul 24 2014 dmitry_r@opensuse.org
- Initial package, version 2.0.1
